/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Content Preferences (cpref).
 *
 * The Initial Developer of the Original Code is Mozilla.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Myk Melez <myk@mozilla.org> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gContentPrefsController = {
  prefHandlers: {},

  // content preferences service
  __cps: null,
  get _cps() {
    if (!this.__cps)
      this.__cps = Cc["@mozilla.org/content-prefs/service;1"].
                   getService(Ci.mozIContentPreferencesService);
    return this.__cps;
  },

  init: function cpc_init() {
    // Listen for onLocationChange so we can apply preferences to the new page.
    // XXX Must some preferences wait for DOMContentLoaded or pageshow?
    gBrowser.addProgressListener(this, Ci.nsIWebProgress.NOTIFY_STATE_DOCUMENT);
  },

  destroy: function cpc_destroy() {
    gBrowser.removeProgressListener(this);

    this.prefHandlers = null;
  },

  registerPrefHandler: function cpc_registerPrefHandler(prefHandler) {
    this.prefHandlers[prefHandler.key] = prefHandler;
  },

  unregisterPrefHandler: function cpc_unregisterPrefHandler(prefHandler) {
    delete this.prefHandlers[prefHandler.key];
  },

  // nsIWebProgressListener

  onLocationChange: function cpc_onLocationChange(progress, request, uri) {
    this.handleLocationChange(uri);
  },
  
  // Stub other nsIWebProgressListener methods to suppress exceptions.
  onStateChange: function cpc_onStateChange(progress, request, flags, status) {},
  onProgressChange: function cpc_onProgressChange(progress, request, curSelfProgress,
                                                  maxSelfProgress, curTotalProgress,
                                                  maxTotalProgress) {},
  onStatusChange: function cpc_onStatusChange(progress, request, status, message) {},
  onSecurityChange: function cpc_onSecurityChange(progress, request, state) {},

  handleLocationChange: function cpc_handleLocationChange(uri) {
    if (uri && uri.spec)
      cpref_log("handle location change; new location: " + uri.spec);

    // It's ok if we don't have a site, since we can still apply global prefs.
    var site;
    try { site = uri.host } catch(ex) {}

    if (this.sidebar && this.sidebar.getElementById("siteLabel")) {
      if (site)
        this.sidebar.getElementById("siteLabel").value = site;
      else 
        this.sidebar.getElementById("siteLabel").value = "???";
    }

    // XXX If we couldn't extract a site from the URI, then do something
    // to disable the sidebar.

    // Get an array of the global preferences, then convert the array
    // into a hash indexed by pref key to make it quicker to look up
    // the corresponding pref for each pref handler below.
    var globalPrefs = {};
    this._cps.getPrefs(null, {}).forEach( function(pref) { globalPrefs[pref.key] = pref } );

    var sitePrefs = {};
    if (site) {
      // Get an array of the site preferences, then convert the array
      // into a hash indexed by pref key to make it quicker to look up
      // the corresponding pref for each pref handler below.
      this._cps.getPrefs(site, {}).forEach( function(pref) { sitePrefs[pref.key] = pref } );
    }

    // For each pref handler, call its location change handler, passing it
    // either the site-specific pref, the global pref, or no pref, depending on
    // what's available.  If we don't pass any pref, the handler should apply
    // some hardcoded default or just ignore the request.
    for (key in this.prefHandlers) {
      var prefHandler = this.prefHandlers[key];
      var pref = sitePrefs[key] || globalPrefs[key];
      var value = pref ? pref.value : null;
      prefHandler.handleLocationChange(value);
    }
  },

  handleSidebarChange: function cpc_handleSidebarChange(key, value) {
    var site = gBrowser.mCurrentBrowser.currentURI.host;
    this.prefHandlers[key].handleSidebarChange(site, value);
  },

  get sidebar() {
    var sidebar = document.getElementById("sidebar");
    if (sidebar && sidebar.getAttribute("src") == "chrome://cpref/content/sidebar.xul")
      return sidebar.contentDocument;
    return null;
  }
};

function cpref_init() {
  gContentPrefsController.init();
}

function cpref_destroy() {
  gContentPrefsController = null;
}

window.addEventListener("load", cpref_init, false);
window.addEventListener("unload", cpref_destroy, false);
