/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Microsummary Buddy.
 *
 * The Initial Developer of the Original Code is Mozilla.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Myk Melez <myk@mozilla.org> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

if (typeof Ci == "undefined") {
  var Ci = Components.interfaces;
  var Cc = Components.classes;
  var Cr = Components.results;
}

function cpref_log(message) {
    if (!cpref_getPref("extensions.cpref.log", false))
        return;

    dump("*** cpref: " +  message + "\n");
    var consoleService = Cc["@mozilla.org/consoleservice;1"].
                         getService(Ci.nsIConsoleService);
    consoleService.logStringMessage("*** cpref: " + message);
};

/**
 * Get a value from a pref or a default value if the pref doesn't exist.
 *
 * @param   prefName
 * @param   defaultValue
 * @returns the pref's value or the default (if it is missing)
 */
function cpref_getPref(prefName, defaultValue) {
    try {
        var prefBranch = Cc["@mozilla.org/preferences-service;1"].
                         getService(Ci.nsIPrefBranch);
        switch (prefBranch.getPrefType(prefName)) {
            case prefBranch.PREF_BOOL:
                return prefBranch.getBoolPref(prefName);
            case prefBranch.PREF_INT:
                return prefBranch.getIntPref(prefName);
        }
    }
    catch (ex) { /* return the default value */ }
    
    return defaultValue;
};

function cpref_enumerateProperties(obj, excludeComplexTypes)
{
  var properties = "";
  for (p in obj)
  {
    try
    {
      if (excludeComplexTypes
          && (typeof obj[p] == 'object' || typeof obj[p] == 'function')) next;
      properties += p + " = " + obj[p] + "\n";
    }
    catch(e) {
      properties += p + " = " + e + "\n";
    }
  }
  return properties;
}

