/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Content Preferences (cpref).
 *
 * The Initial Developer of the Original Code is Mozilla.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Myk Melez <myk@mozilla.org> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const Ci = Components.interfaces;
const Cc = Components.classes;
const Cr = Components.results;

var gMainWindow = window.QueryInterface(Ci.nsIInterfaceRequestor)
                        .getInterface(Ci.nsIWebNavigation)
                        .QueryInterface(Ci.nsIDocShellTreeItem)
                        .rootTreeItem
                        .QueryInterface(Ci.nsIInterfaceRequestor)
                        .getInterface(Ci.nsIDOMWindow);

var gController = {
  // Interfaces this component implements.
  interfaces: [Ci.nsIDOMEventListener, Ci.nsISupports],
  
  // nsISupports
  
  QueryInterface: function sbc_QueryInterface(iid) {
    if (!this.interfaces.some( function(v) { return iid.equals(v) } ))
      throw Cr.NS_ERROR_NO_INTERFACE;
    return this;
  },

  // nsIDOMEventListener

  handleEvent: function sbc_handleEvent(event) {
    this.handleChange(event);
  },

  init: function sbc_init() {
    var sitePrefs = document.getElementById("sitePrefs");
    sitePrefs.addEventListener("change", this, false);

    // Force call handleLocationChange again so the sidebar gets properly
    // initialized when it opens.
    gMainWindow.gContentPrefsController
               .handleLocationChange(gMainWindow.gBrowser.mCurrentBrowser.currentURI);
  },

  destroy: function sbc_destroy() {
    gMainWindow = null;

    var sitePrefs = document.getElementById("sitePrefs");
    sitePrefs.removeEventListener("change", this, false);
  },

  handleChange: function sbc_handleChange(event) {
    var control = event.originalTarget;

    if (control.hasAttribute("updating"))
      return;

    var key = control.getAttribute("key");
    var value = control.value;
    // Work around some bug that may be in the way I copied over the XBL
    // for the scale tag (I couldn't reproduce in a test case).  The value
    // should never be less than one, but if you drag the slider all the way
    // to the left, it winds up zero for some reason.
    if (value == 0)
      value = 1;

    gMainWindow.gContentPrefsController.handleSidebarChange(key, value);
  }
};

function cpref_init() {
  gController.init();
}

function cpref_destroy() {
  gController.destroy();
}

window.addEventListener("load", cpref_init, false);
window.addEventListener("unload", cpref_destroy, false);
